package hwloc;

import hwloc.utils.Tabber;

import java.util.ArrayList;
import java.util.Arrays;

/**
 * 2012
 * @author Emilio Francesquini <francesquini@gmail.com> 
 * 
 */
public class Cache extends CacheAggregator {
	
	protected Core[] cores = null;
	protected long size;
	protected int lineSize;
	protected int level;
	
	public static final String type = "Cache"; 
	
	public void initialize(CacheAggregator parent, long size, int lineSize, int level, Core[] cores, Cache[] caches) {
		this.caches = caches;
		this.cores = cores;		
		this.parent = parent;		
		this.size = size;
		this.lineSize = lineSize;
		this.level = level;
	}
	
	public Core[] getCores() {
		if (cores == null) {
			ArrayList<Core> ret = new ArrayList<Core>();
			for (Cache cache : caches)
				ret.addAll(Arrays.asList(cache.getCores()));
			cores = ret.toArray(new Core[0]);			
		}
		return cores;
	}


	public long getSize() {
		return size;
	}

	
	public int getLineSize() {
		return lineSize;
	}

	
	public int getLevel() {
		return level;
	}
	
	private void printChildrenStringOn(StringBuffer sb, int tabs) {
		MachineHierarchicalNode[] arr = getChildren();
		for (MachineHierarchicalNode node : arr) {
			node.printOn(sb, tabs + 1);
		}
	}
	
	public void printOn(StringBuffer sb, int tabs) {
		Tabber.tab(tabs, sb);
		sb.append("Cache L" + getLevel());		
		sb.append(" Size: " + getSize());
		sb.append(" Line Size: " + getLineSize() + "\n");
		printChildrenStringOn(sb, tabs);
	}

	public MachineHierarchicalNode[] getChildren() {
		return (caches == null) ? cores : caches;		
	}
	
	public boolean isCore() {
		return false;
	}

	public boolean isPU() {
		return false;
	}

	public boolean isCache() {
		return true;
	}

}
