package hwloc;

import hwloc.utils.Tabber;

/**
 * 2012
 * @author Emilio Francesquini <francesquini@gmail.com> 
 * 
 */
public class Node implements MachineHierarchicalNode {
	
	public static final String type = "NUMANode"; 
	
	protected long memory = 0;
	protected int osIndex;
	protected Socket[] sockets = null;
	protected Machine machine;
	
		
	protected Node() {
		super();
	}
	
	protected Node(int osIndex, Machine parent, Socket[] sockets, long memory) {
		this.memory = memory;
		this.sockets = sockets;
		machine = parent;
		this.osIndex = osIndex;
	}
	
	public long getMemory() {
		return memory;
	}
	
	public Socket[] getSockets() {
		return sockets;
	}

	public MachineHierarchicalNode getParent() {
		return machine;
	}
	
	public int getCoreCount() {
		int coreCount = 0;
		for (Socket socket : sockets)
			coreCount += socket.getCoreCount();
		return coreCount;	
	}
	
	private void printChildrenStringOn(StringBuffer sb, int tabs) {
		MachineHierarchicalNode[] arr = getChildren();
		for (MachineHierarchicalNode node : arr)
			node.printOn(sb, tabs + 1);
	}

	public void printOn(StringBuffer sb, int tabs) {
		Tabber.tab(tabs, sb);
		sb.append("NUMANode #" + getOSIndex() + " Memory: " + getMemory() + "\n");
		printChildrenStringOn(sb, tabs);
	}

	public int getOSIndex() {
		return osIndex;
	}

	public MachineHierarchicalNode[] getChildren() {
		return sockets;
	}
		
	public boolean isCore() {
		return false;
	}

	public boolean isPU() {
		return false;
	}

	public boolean isCache() {
		return false;
	}

}
