package hwloc;

import hwloc.utils.Tabber;

import java.util.ArrayList;
import java.util.Arrays;

/**
 * 2012
 * @author Emilio Francesquini <francesquini@gmail.com> 
 * 
 */
public class Socket extends CacheAggregator {

	public static final String type = "Socket"; 
	
	private Core[] cores = null;
	private int osIndex;
	
	public void initialize(int osIndex, Cache[] caches) {
		this.caches = caches;
		this.osIndex = osIndex;
	}

	public Core[] getCores() {
		if (cores == null) {
			ArrayList<Core> ret = new ArrayList<Core>();
			for (Cache cache : caches)
				ret.addAll(Arrays.asList(cache.getCores()));
			cores = ret.toArray(new Core[0]);
		}
		return cores;
	}
	
	public int getCoreCount() {
		return getCores().length;
	}

	
	private void printChildrenStringOn(StringBuffer sb, int tabs) {
		int nTabs = tabs + 1;
		for (Cache cache : caches)
			cache.printOn(sb, nTabs);	
	}
	
	public void printOn(StringBuffer sb, int tabs) {
		Tabber.tab(tabs, sb);
		sb.append("Socket: " + getOSIndex() + "\n");
		printChildrenStringOn(sb, tabs);
	}
	
	public int getOSIndex() {
		return osIndex;
	}

	public MachineHierarchicalNode[] getChildren() {		
		return caches;
	}

	public boolean isCore() {
		return false;
	}

	public boolean isPU() {
		return false;
	}

	public boolean isCache() {
		return false;
	}
	
	
}
